/* Generated by make-libxfce4util-alias.pl. Do not edit this file. */

#ifdef HAVE_GNUC_VISIBILITY

#include <glib.h>

#if 1
#ifdef __LIBXFCE4UTIL_CONFIG_C__
#endif
#endif
#if 1
#ifdef __XFCE_FILEUTILS_C__
#undef xfce_mkdirhier 
extern __typeof (xfce_mkdirhier) xfce_mkdirhier __attribute((alias("IA__xfce_mkdirhier"), visibility("default")));

#endif
#endif
#if 1
#ifdef __XFCE_I18N_C__
#undef xfce_textdomain 
extern __typeof (xfce_textdomain) xfce_textdomain __attribute((alias("IA__xfce_textdomain"), visibility("default")));

#undef xfce_get_file_localized 
extern __typeof (xfce_get_file_localized) xfce_get_file_localized __attribute((alias("IA__xfce_get_file_localized"), visibility("default")));

#undef xfce_get_file_localized_r 
extern __typeof (xfce_get_file_localized_r) xfce_get_file_localized_r __attribute((alias("IA__xfce_get_file_localized_r"), visibility("default")));

#undef xfce_get_dir_localized 
extern __typeof (xfce_get_dir_localized) xfce_get_dir_localized __attribute((alias("IA__xfce_get_dir_localized"), visibility("default")));

#undef xfce_get_dir_localized_r 
extern __typeof (xfce_get_dir_localized_r) xfce_get_dir_localized_r __attribute((alias("IA__xfce_get_dir_localized_r"), visibility("default")));

#undef xfce_get_path_localized 
extern __typeof (xfce_get_path_localized) xfce_get_path_localized __attribute((alias("IA__xfce_get_path_localized"), visibility("default")));

#undef xfce_locale_match 
extern __typeof (xfce_locale_match) xfce_locale_match __attribute((alias("IA__xfce_locale_match"), visibility("default")));

#endif
#endif
#if 1
#ifdef __XFCE_KIOSK_C__
#undef xfce_kiosk_new 
extern __typeof (xfce_kiosk_new) xfce_kiosk_new __attribute((alias("IA__xfce_kiosk_new"), visibility("default")));

#undef xfce_kiosk_query 
extern __typeof (xfce_kiosk_query) xfce_kiosk_query __attribute((alias("IA__xfce_kiosk_query"), visibility("default")));

#undef xfce_kiosk_get_type 
extern __typeof (xfce_kiosk_get_type) xfce_kiosk_get_type __attribute((alias("IA__xfce_kiosk_get_type"), visibility("default")));

#undef xfce_kiosk_free 
extern __typeof (xfce_kiosk_free) xfce_kiosk_free __attribute((alias("IA__xfce_kiosk_free"), visibility("default")));

#endif
#endif
#if 1
#ifdef __XFCE_LICENSE_C__
#undef xfce_get_license_text 
extern __typeof (xfce_get_license_text) xfce_get_license_text __attribute((alias("IA__xfce_get_license_text"), visibility("default")));

#endif
#endif
#if 1
#ifdef __XFCE_MISCUTILS_C__
#undef xfce_version_string 
extern __typeof (xfce_version_string) xfce_version_string __attribute((alias("IA__xfce_version_string"), visibility("default")));

#undef xfce_get_homedir 
extern __typeof (xfce_get_homedir) xfce_get_homedir __attribute((alias("IA__xfce_get_homedir"), visibility("default")));

#undef xfce_get_homefile_r 
extern __typeof (xfce_get_homefile_r) xfce_get_homefile_r __attribute((alias("IA__xfce_get_homefile_r"), visibility("default")));

#undef xfce_get_userdir 
extern __typeof (xfce_get_userdir) xfce_get_userdir __attribute((alias("IA__xfce_get_userdir"), visibility("default")));

#undef xfce_get_userfile_r 
extern __typeof (xfce_get_userfile_r) xfce_get_userfile_r __attribute((alias("IA__xfce_get_userfile_r"), visibility("default")));

#undef xfce_gethostname 
extern __typeof (xfce_gethostname) xfce_gethostname __attribute((alias("IA__xfce_gethostname"), visibility("default")));

#undef xfce_expand_variables 
extern __typeof (xfce_expand_variables) xfce_expand_variables __attribute((alias("IA__xfce_expand_variables"), visibility("default")));

#undef xfce_append_quoted 
extern __typeof (xfce_append_quoted) xfce_append_quoted __attribute((alias("IA__xfce_append_quoted"), visibility("default")));

#undef xfce_expand_desktop_entry_field_codes 
extern __typeof (xfce_expand_desktop_entry_field_codes) xfce_expand_desktop_entry_field_codes __attribute((alias("IA__xfce_expand_desktop_entry_field_codes"), visibility("default")));

#endif
#endif
#if 1
#ifdef __XFCE_POSIX_SIGNAL_HANDLER_C__
#undef xfce_posix_signal_handler_init 
extern __typeof (xfce_posix_signal_handler_init) xfce_posix_signal_handler_init __attribute((alias("IA__xfce_posix_signal_handler_init"), visibility("default")));

#undef xfce_posix_signal_handler_shutdown 
extern __typeof (xfce_posix_signal_handler_shutdown) xfce_posix_signal_handler_shutdown __attribute((alias("IA__xfce_posix_signal_handler_shutdown"), visibility("default")));

#undef xfce_posix_signal_handler_set_handler 
extern __typeof (xfce_posix_signal_handler_set_handler) xfce_posix_signal_handler_set_handler __attribute((alias("IA__xfce_posix_signal_handler_set_handler"), visibility("default")));

#undef xfce_posix_signal_handler_restore_handler 
extern __typeof (xfce_posix_signal_handler_restore_handler) xfce_posix_signal_handler_restore_handler __attribute((alias("IA__xfce_posix_signal_handler_restore_handler"), visibility("default")));

#endif
#endif
#if 1
#ifdef __XFCE_RESOURCE_C__
#undef xfce_resource_dirs 
extern __typeof (xfce_resource_dirs) xfce_resource_dirs __attribute((alias("IA__xfce_resource_dirs"), visibility("default")));

#undef xfce_resource_lookup 
extern __typeof (xfce_resource_lookup) xfce_resource_lookup __attribute((alias("IA__xfce_resource_lookup"), visibility("default")));

#undef xfce_resource_lookup_all 
extern __typeof (xfce_resource_lookup_all) xfce_resource_lookup_all __attribute((alias("IA__xfce_resource_lookup_all"), visibility("default")));

#undef xfce_resource_match 
extern __typeof (xfce_resource_match) xfce_resource_match __attribute((alias("IA__xfce_resource_match"), visibility("default")));

#undef xfce_resource_match_custom 
extern __typeof (xfce_resource_match_custom) xfce_resource_match_custom __attribute((alias("IA__xfce_resource_match_custom"), visibility("default")));

#undef xfce_resource_push_path 
extern __typeof (xfce_resource_push_path) xfce_resource_push_path __attribute((alias("IA__xfce_resource_push_path"), visibility("default")));

#undef xfce_resource_pop_path 
extern __typeof (xfce_resource_pop_path) xfce_resource_pop_path __attribute((alias("IA__xfce_resource_pop_path"), visibility("default")));

#undef xfce_resource_save_location 
extern __typeof (xfce_resource_save_location) xfce_resource_save_location __attribute((alias("IA__xfce_resource_save_location"), visibility("default")));

#endif
#endif
#if 1
#ifdef __XFCE_RC_C__
#undef xfce_rc_get_type 
extern __typeof (xfce_rc_get_type) xfce_rc_get_type __attribute((alias("IA__xfce_rc_get_type"), visibility("default")));

#undef xfce_rc_simple_open 
extern __typeof (xfce_rc_simple_open) xfce_rc_simple_open __attribute((alias("IA__xfce_rc_simple_open"), visibility("default")));

#undef xfce_rc_config_open 
extern __typeof (xfce_rc_config_open) xfce_rc_config_open __attribute((alias("IA__xfce_rc_config_open"), visibility("default")));

#undef xfce_rc_close 
extern __typeof (xfce_rc_close) xfce_rc_close __attribute((alias("IA__xfce_rc_close"), visibility("default")));

#undef xfce_rc_flush 
extern __typeof (xfce_rc_flush) xfce_rc_flush __attribute((alias("IA__xfce_rc_flush"), visibility("default")));

#undef xfce_rc_rollback 
extern __typeof (xfce_rc_rollback) xfce_rc_rollback __attribute((alias("IA__xfce_rc_rollback"), visibility("default")));

#undef xfce_rc_is_dirty 
extern __typeof (xfce_rc_is_dirty) xfce_rc_is_dirty __attribute((alias("IA__xfce_rc_is_dirty"), visibility("default")));

#undef xfce_rc_is_readonly 
extern __typeof (xfce_rc_is_readonly) xfce_rc_is_readonly __attribute((alias("IA__xfce_rc_is_readonly"), visibility("default")));

#undef xfce_rc_get_locale 
extern __typeof (xfce_rc_get_locale) xfce_rc_get_locale __attribute((alias("IA__xfce_rc_get_locale"), visibility("default")));

#undef xfce_rc_get_groups 
extern __typeof (xfce_rc_get_groups) xfce_rc_get_groups __attribute((alias("IA__xfce_rc_get_groups"), visibility("default")));

#undef xfce_rc_get_entries 
extern __typeof (xfce_rc_get_entries) xfce_rc_get_entries __attribute((alias("IA__xfce_rc_get_entries"), visibility("default")));

#undef xfce_rc_delete_group 
extern __typeof (xfce_rc_delete_group) xfce_rc_delete_group __attribute((alias("IA__xfce_rc_delete_group"), visibility("default")));

#undef xfce_rc_get_group 
extern __typeof (xfce_rc_get_group) xfce_rc_get_group __attribute((alias("IA__xfce_rc_get_group"), visibility("default")));

#undef xfce_rc_has_group 
extern __typeof (xfce_rc_has_group) xfce_rc_has_group __attribute((alias("IA__xfce_rc_has_group"), visibility("default")));

#undef xfce_rc_set_group 
extern __typeof (xfce_rc_set_group) xfce_rc_set_group __attribute((alias("IA__xfce_rc_set_group"), visibility("default")));

#undef xfce_rc_delete_entry 
extern __typeof (xfce_rc_delete_entry) xfce_rc_delete_entry __attribute((alias("IA__xfce_rc_delete_entry"), visibility("default")));

#undef xfce_rc_has_entry 
extern __typeof (xfce_rc_has_entry) xfce_rc_has_entry __attribute((alias("IA__xfce_rc_has_entry"), visibility("default")));

#undef xfce_rc_read_entry 
extern __typeof (xfce_rc_read_entry) xfce_rc_read_entry __attribute((alias("IA__xfce_rc_read_entry"), visibility("default")));

#undef xfce_rc_read_entry_untranslated 
extern __typeof (xfce_rc_read_entry_untranslated) xfce_rc_read_entry_untranslated __attribute((alias("IA__xfce_rc_read_entry_untranslated"), visibility("default")));

#undef xfce_rc_read_bool_entry 
extern __typeof (xfce_rc_read_bool_entry) xfce_rc_read_bool_entry __attribute((alias("IA__xfce_rc_read_bool_entry"), visibility("default")));

#undef xfce_rc_read_int_entry 
extern __typeof (xfce_rc_read_int_entry) xfce_rc_read_int_entry __attribute((alias("IA__xfce_rc_read_int_entry"), visibility("default")));

#undef xfce_rc_read_list_entry 
extern __typeof (xfce_rc_read_list_entry) xfce_rc_read_list_entry __attribute((alias("IA__xfce_rc_read_list_entry"), visibility("default")));

#undef xfce_rc_write_entry 
extern __typeof (xfce_rc_write_entry) xfce_rc_write_entry __attribute((alias("IA__xfce_rc_write_entry"), visibility("default")));

#undef xfce_rc_write_bool_entry 
extern __typeof (xfce_rc_write_bool_entry) xfce_rc_write_bool_entry __attribute((alias("IA__xfce_rc_write_bool_entry"), visibility("default")));

#undef xfce_rc_write_int_entry 
extern __typeof (xfce_rc_write_int_entry) xfce_rc_write_int_entry __attribute((alias("IA__xfce_rc_write_int_entry"), visibility("default")));

#undef xfce_rc_write_list_entry 
extern __typeof (xfce_rc_write_list_entry) xfce_rc_write_list_entry __attribute((alias("IA__xfce_rc_write_list_entry"), visibility("default")));

#endif
#endif
#if 1
#ifdef __XFCE_UTF8_C__
#undef xfce_utf8_remove_controls 
extern __typeof (xfce_utf8_remove_controls) xfce_utf8_remove_controls __attribute((alias("IA__xfce_utf8_remove_controls"), visibility("default")));

#undef xfce_utf8_strndup 
extern __typeof (xfce_utf8_strndup) xfce_utf8_strndup __attribute((alias("IA__xfce_utf8_strndup"), visibility("default")));

#endif
#endif

#endif /* HAVE_GNUC_VISIBILITY */
